@@ -2,6 +2,7 @@
 /* Generated data (by glib-mkenums) */
 
 #include <libxfce4ui/libxfce4ui.h>
+#include <libxfce4ui/libxfce4ui-alias.h>
 
 /* enumerations from "xfce-sm-client.h" */
 
@@ -22,27 +23,6 @@ xfce_sm_client_restart_style_get_type(void)
     return type;
 }
 
-GType
-xfce_sm_client_priority_get_type(void)
-{
-    static GType type = 0;
-
-    if(!type) {
-        static const GEnumValue values[] = {
-            { XFCE_SM_CLIENT_PRIORITY_HIGHEST, "XFCE_SM_CLIENT_PRIORITY_HIGHEST", "highest" },
-            { XFCE_SM_CLIENT_PRIORITY_WM, "XFCE_SM_CLIENT_PRIORITY_WM", "wm" },
-            { XFCE_SM_CLIENT_PRIORITY_CORE, "XFCE_SM_CLIENT_PRIORITY_CORE", "core" },
-            { XFCE_SM_CLIENT_PRIORITY_DESKTOP, "XFCE_SM_CLIENT_PRIORITY_DESKTOP", "desktop" },
-            { XFCE_SM_CLIENT_PRIORITY_DEFAULT, "XFCE_SM_CLIENT_PRIORITY_DEFAULT", "default" },
-            { XFCE_SM_CLIENT_PRIORITY_LOWEST, "XFCE_SM_CLIENT_PRIORITY_LOWEST", "lowest" },
-            { 0, NULL, NULL }
-	};
-	type = g_enum_register_static("XfceSMClientPriority", values);
-    }
-
-    return type;
-}
-
 GType
 xfce_sm_client_shutdown_hint_get_type(void)
 {
@@ -63,5 +43,8 @@ xfce_sm_client_shutdown_hint_get_type(void)
 }
 
 
+#define __LIBXFCE4UI_ENUM_TYPES_C__
+#include <libxfce4ui/libxfce4ui-aliasdef.c>
+
 /* Generated data ends here */
 
