@@ -11,9 +11,6 @@ G_BEGIN_DECLS
 GType xfce_sm_client_restart_style_get_type(void) G_GNUC_CONST;
 #define XFCE_TYPE_SM_CLIENT_RESTART_STYLE (xfce_sm_client_restart_style_get_type())
 
-GType xfce_sm_client_priority_get_type(void) G_GNUC_CONST;
-#define XFCE_TYPE_SM_CLIENT_PRIORITY (xfce_sm_client_priority_get_type())
-
 GType xfce_sm_client_shutdown_hint_get_type(void) G_GNUC_CONST;
 #define XFCE_TYPE_SM_CLIENT_SHUTDOWN_HINT (xfce_sm_client_shutdown_hint_get_type())
 
